@@ -89,28 +89,28 @@ on_bootproto_changed (GtkWidget *widget, gpointer data)
   gtk_widget_set_sensitive (dialog->gateway, enabled);
 }
 
-void
-on_connection_cancel_clicked (GtkWidget *widget, gpointer data)
+static void
+cancel_connection_dialog (GstTool *tool)
 {
   GstConnectionDialog *dialog;
 
   dialog = GST_NETWORK_TOOL (tool)->dialog;
   g_object_unref (dialog->iface);
-  gtk_widget_hide (dialog->dialog);
+  connection_dialog_hide (dialog);
 
   if (dialog->standalone)
     gtk_main_quit ();
 }
 
-void
-on_connection_ok_clicked (GtkWidget *widget, gpointer data)
+static void
+accept_connection_dialog (GstTool *tool)
 {
   GstConnectionDialog *dialog;
   GtkTreeSelection    *selection;
   GtkTreeIter          iter;
 
   dialog = GST_NETWORK_TOOL (tool)->dialog;
-  gtk_widget_hide (dialog->dialog);
+  connection_dialog_hide (dialog);
 
   if (dialog->changed)
     {
@@ -123,7 +123,7 @@ on_connection_ok_clicked (GtkWidget *widget, gpointer data)
 	  g_signal_emit_by_name (G_OBJECT (selection), "changed");
 	}
 
-      gst_tool_commit_async (tool, GST_NETWORK_TOOL (tool)->ifaces_config,
+      gst_tool_commit_async (tool, OOBS_OBJECT (GST_NETWORK_TOOL (tool)->ifaces_config),
 			     _("Changing interface configuration"));
     }
 
@@ -133,6 +133,20 @@ on_connection_ok_clicked (GtkWidget *widget, gpointer data)
     gtk_main_quit ();
 }
 
+void
+on_connection_response (GtkWidget *widget,
+			gint       response,
+			gpointer   data)
+{
+  GstDialog *dialog = GST_DIALOG (data);
+  GstTool *tool = gst_dialog_get_tool (dialog);
+
+  if (response == GTK_RESPONSE_OK)
+    accept_connection_dialog (tool);
+  else
+    cancel_connection_dialog (tool);
+}
+
 void
 on_detect_modem_clicked (GtkWidget *widget, gpointer data)
 {
@@ -324,13 +338,6 @@ on_ip_address_focus_out (GtkWidget *widget, GdkEventFocus *event, gpointer data)
   return FALSE;
 }
 
-gboolean
-on_connection_dialog_close (GtkWidget *widget, GdkEvent *event, gpointer data)
-{
-  gtk_widget_hide (widget);
-  return TRUE;
-}
-
 void
 on_iface_toggled (GtkCellRendererToggle *renderer,
 		  gchar                 *path_str,
@@ -360,7 +367,7 @@ on_iface_toggled (GtkCellRendererToggle *renderer,
 	  oobs_iface_set_auto (iface, active);
 	  ifaces_model_modify_interface_at_iter (&iter);
 
-	  gst_tool_commit_async (tool, GST_NETWORK_TOOL (tool)->ifaces_config,
+	  gst_tool_commit_async (tool, OOBS_OBJECT (GST_NETWORK_TOOL (tool)->ifaces_config),
 				 _("Activating network interface"));
 	}
 
@@ -381,7 +388,7 @@ on_hostname_focus_out (GtkWidget *widget, GdkEventFocus *event, gpointer data)
 {
   GstNetworkTool *tool;
   gboolean changed;
-  gchar *hostname;
+  const gchar *hostname;
 
   tool = GST_NETWORK_TOOL (gst_dialog_get_tool (GST_DIALOG (data)));
   changed = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (widget), "content-changed"));
@@ -414,7 +421,7 @@ on_hostname_focus_out (GtkWidget *widget, GdkEventFocus *event, gpointer data)
       if (res == GTK_RESPONSE_ACCEPT)
 	{
 	  oobs_hosts_config_set_hostname (tool->hosts_config, hostname);
-	  oobs_object_commit (tool->hosts_config);
+	  oobs_object_commit (OOBS_OBJECT (tool->hosts_config));
 	}
       else
 	{
@@ -433,7 +440,7 @@ on_domain_focus_out (GtkWidget *widget, GdkEventFocus *event, gpointer data)
 {
   GstNetworkTool *tool;
   gboolean changed;
-  gchar *domain;
+  const gchar *domain;
 
   tool = GST_NETWORK_TOOL (gst_dialog_get_tool (GST_DIALOG (data)));
   changed = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (widget), "content-changed"));
@@ -442,7 +449,7 @@ on_domain_focus_out (GtkWidget *widget, GdkEventFocus *event, gpointer data)
   if (changed)
     {
       oobs_hosts_config_set_domainname (tool->hosts_config, domain);
-      oobs_object_commit (tool->hosts_config);
+      oobs_object_commit (OOBS_OBJECT (tool->hosts_config));
     }
 
   g_object_set_data (G_OBJECT (widget), "content-changed", GINT_TO_POINTER (FALSE));
